
# Slot: inherited


true means that the *value* of a slot is inherited by subclasses

URI: [linkml:inherited](https://w3id.org/linkml/inherited)


## Domain and Range

slot_definition &#8594;  <sub>0..1</sub> boolean

## Parents


## Children


## Used by

 * slot_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | Inherited applies to slot values.  Parent *slots* are always inherited by subclasses |

